var searchData=
[
  ['scaledidentityaddable_0',['ScaledIdentityAddable',['../classgko_1_1ScaledIdentityAddable.html',1,'gko']]],
  ['scaledpermutation_1',['ScaledPermutation',['../classgko_1_1matrix_1_1ScaledPermutation.html',1,'gko::matrix']]],
  ['scaledreordered_2',['ScaledReordered',['../classgko_1_1experimental_1_1reorder_1_1ScaledReordered.html',1,'gko::experimental::reorder']]],
  ['schwarz_3',['Schwarz',['../classgko_1_1experimental_1_1distributed_1_1preconditioner_1_1Schwarz.html',1,'gko::experimental::distributed::preconditioner']]],
  ['scoped_5fdevice_5fid_5fguard_4',['scoped_device_id_guard',['../classgko_1_1scoped__device__id__guard.html',1,'gko']]],
  ['segmented_5farray_5',['segmented_array',['../structgko_1_1segmented__array.html',1,'gko']]],
  ['segmented_5farray_3c_20int64_20_3e_6',['segmented_array&lt; int64 &gt;',['../structgko_1_1segmented__array.html',1,'gko']]],
  ['segmented_5farray_3c_20localindextype_20_3e_7',['segmented_array&lt; LocalIndexType &gt;',['../structgko_1_1segmented__array.html',1,'gko']]],
  ['sellp_8',['Sellp',['../classgko_1_1matrix_1_1Sellp.html',1,'gko::matrix']]],
  ['solverbase_9',['SolverBase',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
  ['solverbase_3c_20factorization_3a_3afactorization_3c_20valuetype_2c_20indextype_20_3e_20_3e_10',['SolverBase&lt; factorization::Factorization&lt; ValueType, IndexType &gt; &gt;',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
  ['solverbase_3c_20linop_20_3e_11',['SolverBase&lt; LinOp &gt;',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
  ['solverbase_3c_20matrix_3a_3acsr_3c_20default_5fprecision_2c_20int32_20_3e_20_3e_12',['SolverBase&lt; matrix::Csr&lt; default_precision, int32 &gt; &gt;',['../classgko_1_1solver_1_1SolverBase.html',1,'gko::solver']]],
  ['solverprogress_13',['SolverProgress',['../classgko_1_1log_1_1SolverProgress.html',1,'gko::log']]],
  ['sor_14',['Sor',['../classgko_1_1preconditioner_1_1Sor.html',1,'gko::preconditioner']]],
  ['span_15',['span',['../structgko_1_1span.html',1,'gko']]],
  ['sparselib_16',['sparselib',['../classgko_1_1matrix_1_1Csr_1_1sparselib.html',1,'gko::matrix::Csr']]],
  ['sparsitycsr_17',['SparsityCsr',['../classgko_1_1matrix_1_1SparsityCsr.html',1,'gko::matrix']]],
  ['squared_5fnorm_5foperation_18',['squared_norm_operation',['../structgko_1_1accessor_1_1squared__norm__operation.html',1,'gko::accessor']]],
  ['squared_5fnorm_5foperaton_19',['squared_norm_operaton',['../structgko_1_1accessor_1_1squared__norm__operaton.html',1,'gko::accessor']]],
  ['status_20',['status',['../structgko_1_1experimental_1_1mpi_1_1status.html',1,'gko::experimental::mpi']]],
  ['stopping_5fstatus_21',['stopping_status',['../classgko_1_1stopping__status.html',1,'gko']]],
  ['strategy_5ftype_22',['strategy_type',['../classgko_1_1matrix_1_1Csr_1_1strategy__type.html',1,'gko::matrix::Csr&lt; ValueType, IndexType &gt;::strategy_type'],['../classgko_1_1matrix_1_1Hybrid_1_1strategy__type.html',1,'gko::matrix::Hybrid&lt; ValueType, IndexType &gt;::strategy_type']]],
  ['stream_23',['Stream',['../classgko_1_1log_1_1Stream.html',1,'gko::log']]],
  ['streamerror_24',['StreamError',['../classgko_1_1StreamError.html',1,'gko']]],
  ['sub_25',['sub',['../structgko_1_1accessor_1_1sub.html',1,'gko::accessor']]],
  ['summary_5fentry_26',['summary_entry',['../structgko_1_1log_1_1ProfilerHook_1_1summary__entry.html',1,'gko::log::ProfilerHook']]],
  ['summarywriter_27',['SummaryWriter',['../classgko_1_1log_1_1ProfilerHook_1_1SummaryWriter.html',1,'gko::log::ProfilerHook']]]
];
